==> qtjambi-designer-5.15.4-sources.jar: io/qt/designer/QDesignerActionEditorInterface.java <==
package io.qt.designer;


/**
 * <p>Allows you to change the focus of Qt Designer's action editor</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html">QDesignerActionEditorInterface</a></p>
 */
public abstract class QDesignerActionEditorInterface extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcFormWindow = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDesignerActionEditorInterface.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QDesignerActionEditorInterface {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void manageAction(io.qt.widgets.QAction action){
            manageAction_native_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
        }
        @io.qt.QtUninvokable
        private native void manageAction_native_QAction_ptr(long __this__nativeId, long action);
        
        
        @Override
        public void setFormWindow(io.qt.designer.QDesignerFormWindowInterface formWindow){
            setFormWindow_native_QDesignerFormWindowInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(formWindow));
            QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.designer.QDesignerActionEditorInterface.class, "__rcFormWindow", false, false, formWindow);
        }
        private native void setFormWindow_native_QDesignerFormWindowInterface_ptr(long __this__nativeId, long formWindow);
        
        
        @Override
        @io.qt.QtUninvokable
        public void unmanageAction(io.qt.widgets.QAction action){
            unmanageAction_native_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
        }
        @io.qt.QtUninvokable
        private native void unmanageAction_native_QAction_ptr(long __this__nativeId, long action);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerActionEditorInterface(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}.</p>
     */
    public QDesignerActionEditorInterface(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowType ... flags){
        this(parent, new io.qt.core.Qt.WindowFlags(flags));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerActionEditorInterface(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}
     *  with <code>flags = new io.qt.core.Qt.WindowFlags(0)</code>.</p>
     */
    public QDesignerActionEditorInterface(io.qt.widgets.QWidget parent) {
        this(parent, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#QDesignerActionEditorInterface">QDesignerActionEditorInterface::QDesignerActionEditorInterface(QWidget*,Qt::WindowFlags)</a></p>
     */
    public QDesignerActionEditorInterface(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags){
        super((QPrivateConstructor)null);
        initialize_native(this, parent, flags);
    }
    
    private native static void initialize_native(QDesignerActionEditorInterface instance, io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#core">QDesignerActionEditorInterface::core()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerFormEditorInterface core(){
        return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#manageAction">QDesignerActionEditorInterface::manageAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void manageAction(io.qt.widgets.QAction action);
    
    @io.qt.QtUninvokable
    private native void manageAction_native_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#setFormWindow">QDesignerActionEditorInterface::setFormWindow(QDesignerFormWindowInterface*)</a></p>
     */
    public abstract void setFormWindow(io.qt.designer.QDesignerFormWindowInterface formWindow);
    
    private native void setFormWindow_native_QDesignerFormWindowInterface_ptr(long __this__nativeId, long formWindow);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#unmanageAction">QDesignerActionEditorInterface::unmanageAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void unmanageAction(io.qt.widgets.QAction action);
    
    @io.qt.QtUninvokable
    private native void unmanageAction_native_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDesignerActionEditorInterface(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QDesignerActionEditorInterface.java <==
package io.qt.designer;


/**
 * <p>Allows you to change the focus of Qt Designer's action editor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html">QDesignerActionEditorInterface</a></p>
 */
public abstract class QDesignerActionEditorInterface extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    @io.qt.QtPropertyMember(enabled=false)
    private Object __rcFormWindow = null;
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDesignerActionEditorInterface.class);
    
    @io.qt.NativeAccess
    private static final class ConcreteWrapper extends QDesignerActionEditorInterface {
        
        @io.qt.NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @io.qt.QtUninvokable
        public void manageAction(io.qt.widgets.QAction action){
            manageAction_native_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
        }
        @io.qt.QtUninvokable
        private native void manageAction_native_QAction_ptr(long __this__nativeId, long action);
        
        
        @Override
        public void setFormWindow(io.qt.designer.QDesignerFormWindowInterface formWindow){
            setFormWindow_native_QDesignerFormWindowInterface_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(formWindow));
            QtJambi_LibraryUtilities.internal.setReferenceCount(this, io.qt.designer.QDesignerActionEditorInterface.class, "__rcFormWindow", false, false, formWindow);
        }
        private native void setFormWindow_native_QDesignerFormWindowInterface_ptr(long __this__nativeId, long formWindow);
        
        
        @Override
        @io.qt.QtUninvokable
        public void unmanageAction(io.qt.widgets.QAction action){
            unmanageAction_native_QAction_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(action));
        }
        @io.qt.QtUninvokable
        private native void unmanageAction_native_QAction_ptr(long __this__nativeId, long action);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerActionEditorInterface(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}.</p>
     */
    public QDesignerActionEditorInterface(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowType ... flags){
        this(parent, new io.qt.core.Qt.WindowFlags(flags));
    }
    
    /**
     * <p>Overloaded constructor for {@link #QDesignerActionEditorInterface(io.qt.widgets.QWidget, io.qt.core.Qt.WindowFlags)}
     *  with <code>flags = new io.qt.core.Qt.WindowFlags(0)</code>.</p>
     */
    public QDesignerActionEditorInterface(io.qt.widgets.QWidget parent) {
        this(parent, new io.qt.core.Qt.WindowFlags(0));
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#QDesignerActionEditorInterface">QDesignerActionEditorInterface::QDesignerActionEditorInterface(QWidget*,Qt::WindowFlags)</a></p>
     */
    public QDesignerActionEditorInterface(io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags){
        super((QPrivateConstructor)null);
        initialize_native(this, parent, flags);
    }
    
    private native static void initialize_native(QDesignerActionEditorInterface instance, io.qt.widgets.QWidget parent, io.qt.core.Qt.WindowFlags flags);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#core">QDesignerActionEditorInterface::core()const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.designer.QDesignerFormEditorInterface core(){
        return core_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.designer.QDesignerFormEditorInterface core_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#manageAction">QDesignerActionEditorInterface::manageAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void manageAction(io.qt.widgets.QAction action);
    
    @io.qt.QtUninvokable
    private native void manageAction_native_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#setFormWindow">QDesignerActionEditorInterface::setFormWindow(QDesignerFormWindowInterface*)</a></p>
     */
    public abstract void setFormWindow(io.qt.designer.QDesignerFormWindowInterface formWindow);
    
    private native void setFormWindow_native_QDesignerFormWindowInterface_ptr(long __this__nativeId, long formWindow);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qdesigneractioneditorinterface.html#unmanageAction">QDesignerActionEditorInterface::unmanageAction(QAction*)</a></p>
     */
    @io.qt.QtUninvokable
    public abstract void unmanageAction(io.qt.widgets.QAction action);
    
    @io.qt.QtUninvokable
    private native void unmanageAction_native_QAction_ptr(long __this__nativeId, long action);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDesignerActionEditorInterface(QPrivateConstructor p) { super(p); } 
    
}
